function band=meshband(mh,outerdomain,varargin)

	%process options: 
	options=pairoptions(varargin{:});

	%some checks on the mesh: 
	if (isempty(mh.x) | isempty(mh.y)  ) 
		error('meshband error message: mesh has one of the following empty: ''x'',''y''');
	end

	%give ourselves a unique temporary directory: 
	temproot=tempname; mkdir(temproot);

	%align external segments on internal mesh: 
	mh.segments=alignsegments(mh.segments);

	%figure out domain outline: 
	meshtodomain(mh,[temproot '/innerdomain.exp']);

	%create domain outine from inner and outer domain
	inner=expread([temproot '/innerdomain.exp']);
	if inner.closed==0,
		inner.nods=inner.nods+1;
		inner.x(end+1)=inner.x(1);
		inner.y(end+1)=inner.y(1);
		inner.closed=1;
		if getfieldvalue(options,'invert',0),
			inner.x=flipud(inner.x);
			inner.y=flipud(inner.y);
		end
	end
	outer=expread(outerdomain);

	domain(1)=outer;
	domain(2)=inner;
	
	expwrite(domain,[temproot '/Band.exp']);
	
	if getfieldvalue(options,'plot',0),
		figure(1),clf,hold on,axis image;
		expdisp([temproot '/Band.exp'],'linestyle','k-*');
	end

	%mesh: 
	md=bamg(model(),'domain',[temproot '/Band.exp'],'MaxCornerAngle',1e-15,'gradation',10000); band=md.mesh; clear md;

	if getfieldvalue(options,'plot',0),
		trisurf(band.elements,band.x,band.y,band.x),view(2),shading faceted;
	end
	
	if length(band.segments) ~= (length(domain(1).x)+length(domain(2).x)-2),
		error('band mesh not consistent');
	end

	%erase temporary directory: 
	system(['rm -rf ' temproot]);

end
